Google — Velruse 1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »

# Google

Velruse supports authentication and authorizing users with Google services using both their hybrid OpenID+OAuth1.0 and their OAuth2.0 protocols. Users may choose which to implement, or both.

- Google Hybrid (OpenID+OAuth) - `velruse.providers.google_hybrid`
- Google OAuth2.0 - `velruse.providers.google_oauth2`

### Navigation

- index
- modules |
- next |
- previous |
- Velruse 1.1 documentation »
- Provider Documentation »